@@ -1,17 +1,12 @@
-/****************************************************************************
-
- KHotKeys
-
- Copyright (C) 2003 Mike Pilone <mpilone@slac.com>
- Copyright (C) 2003 Lubos Lunak <l.lunak@kde.org>
-
- Distributed under the terms of the GNU General Public License version 2.
-
-****************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-only
+    SPDX-FileCopyrightText: 2003 Mike Pilone <mpilone@slac.com>
+    SPDX-FileCopyrightText: 2003 Lubos Lunak <l.lunak@kde.org>
+    SPDX-FileCopyrightText: 2009 Michael Jansen <kde@michael-jansen.biz>
+ */
 
 #include <QEvent>
 #include <QColor>
-#include <QFrame>
 #include <QMouseEvent>
 
 #include "gesture_recorder.h"
